Class: Google::Apis::DnsV1beta2::ManagedZonesListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedZonesListResponse

Returns a new instance of ManagedZonesListResponse.



1416
1417
1418
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


1397
1398
1399
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1397

def kind
  @kind
end

#managed_zonesArray<Google::Apis::DnsV1beta2::ManagedZone>

The managed zone resources. Corresponds to the JSON property managedZones



1402
1403
1404
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1402

def managed_zones
  @managed_zones
end

#next_page_tokenString

This field indicates that more results are available beyond the last page displayed. To fetch the results, make another list request and use this value as your page token. This lets you retrieve the complete contents of a very large collection one page at a time. However, if the contents of the collection change between the first and last paginated list request, the set of all elements returned are an inconsistent view of the collection. You can't retrieve a consistent snapshot of a collection larger than the maximum page size. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1414
1415
1416
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1414

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1421
1422
1423
1424
1425
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1421

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @managed_zones = args[:managed_zones] if args.key?(:managed_zones)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end