Class: Google::Apis::DnsV1beta2::PolicyDns64ConfigScope
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::PolicyDns64ConfigScope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Instance Attribute Summary collapse
-
#all_queries ⇒ Boolean
(also: #all_queries?)
Controls whether DNS64 is enabled globally for all networks bound to the policy.
-
#kind ⇒ String
Corresponds to the JSON property
kind.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PolicyDns64ConfigScope
constructor
A new instance of PolicyDns64ConfigScope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PolicyDns64ConfigScope
Returns a new instance of PolicyDns64ConfigScope.
1818 1819 1820 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1818 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_queries ⇒ Boolean Also known as: all_queries?
Controls whether DNS64 is enabled globally for all networks bound to the
policy.
Corresponds to the JSON property allQueries
1810 1811 1812 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1810 def all_queries @all_queries end |
#kind ⇒ String
Corresponds to the JSON property kind
1816 1817 1818 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1816 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1823 1824 1825 1826 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1823 def update!(**args) @all_queries = args[:all_queries] if args.key?(:all_queries) @kind = args[:kind] if args.key?(:kind) end |