Class: Google::Apis::DnsV1beta2::ResponsePoliciesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::ResponsePoliciesListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page displayed.
-
#response_policies ⇒ Array<Google::Apis::DnsV1beta2::ResponsePolicy>
The Response Policy resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResponsePoliciesListResponse
constructor
A new instance of ResponsePoliciesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResponsePoliciesListResponse
Returns a new instance of ResponsePoliciesListResponse.
2558 2559 2560 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page
displayed. To fetch the results, make another list request and use this value
as your page token. This lets you retrieve the complete contents of a very
large collection one page at a time. However, if the contents of the
collection change between the first and last paginated list request, the set
of all elements returned are an inconsistent view of the collection. You can't
retrieve a consistent snapshot of a collection larger than the maximum page
size.
Corresponds to the JSON property nextPageToken
2551 2552 2553 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2551 def next_page_token @next_page_token end |
#response_policies ⇒ Array<Google::Apis::DnsV1beta2::ResponsePolicy>
The Response Policy resources.
Corresponds to the JSON property responsePolicies
2556 2557 2558 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2556 def response_policies @response_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2563 2564 2565 2566 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2563 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @response_policies = args[:response_policies] if args.key?(:response_policies) end |