Class: Google::Apis::DnsV1beta2::ResponsePoliciesUpdateResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResponsePoliciesUpdateResponse

Returns a new instance of ResponsePoliciesUpdateResponse.



2599
2600
2601
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#response_policyGoogle::Apis::DnsV1beta2::ResponsePolicy

A Response Policy is a collection of selectors that apply to queries made against one or more Virtual Private Cloud networks. Corresponds to the JSON property responsePolicy



2597
2598
2599
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2597

def response_policy
  @response_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2604
2605
2606
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2604

def update!(**args)
  @response_policy = args[:response_policy] if args.key?(:response_policy)
end