Class: Google::Apis::DnsV1beta2::ResponsePolicy
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::ResponsePolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Overview
A Response Policy is a collection of selectors that apply to queries made against one or more Virtual Private Cloud networks.
Instance Attribute Summary collapse
-
#description ⇒ String
User-provided description for this Response Policy.
-
#gke_clusters ⇒ Array<Google::Apis::DnsV1beta2::ResponsePolicyGkeCluster>
The list of Google Kubernetes Engine clusters to which this response policy is applied.
-
#id ⇒ Fixnum
Unique identifier for the resource; defined by the server (output only).
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#labels ⇒ Hash<String,String>
User labels.
-
#networks ⇒ Array<Google::Apis::DnsV1beta2::ResponsePolicyNetwork>
List of network names specifying networks to which this policy is applied.
-
#response_policy_name ⇒ String
User assigned name for this Response Policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResponsePolicy
constructor
A new instance of ResponsePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResponsePolicy
Returns a new instance of ResponsePolicy.
2650 2651 2652 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
User-provided description for this Response Policy.
Corresponds to the JSON property description
2617 2618 2619 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2617 def description @description end |
#gke_clusters ⇒ Array<Google::Apis::DnsV1beta2::ResponsePolicyGkeCluster>
The list of Google Kubernetes Engine clusters to which this response policy is
applied.
Corresponds to the JSON property gkeClusters
2623 2624 2625 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2623 def gke_clusters @gke_clusters end |
#id ⇒ Fixnum
Unique identifier for the resource; defined by the server (output only).
Corresponds to the JSON property id
2628 2629 2630 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2628 def id @id end |
#kind ⇒ String
Corresponds to the JSON property kind
2633 2634 2635 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2633 def kind @kind end |
#labels ⇒ Hash<String,String>
User labels.
Corresponds to the JSON property labels
2638 2639 2640 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2638 def labels @labels end |
#networks ⇒ Array<Google::Apis::DnsV1beta2::ResponsePolicyNetwork>
List of network names specifying networks to which this policy is applied.
Corresponds to the JSON property networks
2643 2644 2645 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2643 def networks @networks end |
#response_policy_name ⇒ String
User assigned name for this Response Policy.
Corresponds to the JSON property responsePolicyName
2648 2649 2650 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2648 def response_policy_name @response_policy_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2655 2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2655 def update!(**args) @description = args[:description] if args.key?(:description) @gke_clusters = args[:gke_clusters] if args.key?(:gke_clusters) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @labels = args[:labels] if args.key?(:labels) @networks = args[:networks] if args.key?(:networks) @response_policy_name = args[:response_policy_name] if args.key?(:response_policy_name) end |