Class: Google::Apis::DnsV1beta2::RrSetRoutingPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb

Overview

A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RrSetRoutingPolicy

Returns a new instance of RrSetRoutingPolicy.



2117
2118
2119
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geoGoogle::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicy

Configures a RRSetRoutingPolicy that routes based on the geo location of the querying user. Corresponds to the JSON property geo



2079
2080
2081
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2079

def geo
  @geo
end

#geo_policyGoogle::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicy

Configures a RRSetRoutingPolicy that routes based on the geo location of the querying user. Corresponds to the JSON property geoPolicy



2085
2086
2087
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2085

def geo_policy
  @geo_policy
end

#health_checkString

The fully qualified URL of the HealthCheck to use for this RRSetRoutingPolicy. Format this URL like https://www.googleapis.com/compute/v1/projects/project/ global/healthChecks/healthCheck`. https://cloud.google.com/compute/docs/ reference/rest/v1/healthChecks Corresponds to the JSON propertyhealthCheck`

Returns:

  • (String)


2093
2094
2095
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2093

def health_check
  @health_check
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


2098
2099
2100
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2098

def kind
  @kind
end

#primary_backupGoogle::Apis::DnsV1beta2::RrSetRoutingPolicyPrimaryBackupPolicy

Configures a RRSetRoutingPolicy such that all queries are responded with the primary_targets if they are healthy. And if all of them are unhealthy, then we fallback to a geo localized policy. Corresponds to the JSON property primaryBackup



2105
2106
2107
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2105

def primary_backup
  @primary_backup
end

#wrrGoogle::Apis::DnsV1beta2::RrSetRoutingPolicyWrrPolicy

Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion. Corresponds to the JSON property wrr



2110
2111
2112
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2110

def wrr
  @wrr
end

#wrr_policyGoogle::Apis::DnsV1beta2::RrSetRoutingPolicyWrrPolicy

Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion. Corresponds to the JSON property wrrPolicy



2115
2116
2117
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2115

def wrr_policy
  @wrr_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2122

def update!(**args)
  @geo = args[:geo] if args.key?(:geo)
  @geo_policy = args[:geo_policy] if args.key?(:geo_policy)
  @health_check = args[:health_check] if args.key?(:health_check)
  @kind = args[:kind] if args.key?(:kind)
  @primary_backup = args[:primary_backup] if args.key?(:primary_backup)
  @wrr = args[:wrr] if args.key?(:wrr)
  @wrr_policy = args[:wrr_policy] if args.key?(:wrr_policy)
end