Class: Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicyGeoPolicyItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb

Overview

ResourceRecordSet data for one geo location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RrSetRoutingPolicyGeoPolicyGeoPolicyItem

Returns a new instance of RrSetRoutingPolicyGeoPolicyGeoPolicyItem.



2208
2209
2210
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#health_checked_targetsGoogle::Apis::DnsV1beta2::RrSetRoutingPolicyHealthCheckTargets

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both. Corresponds to the JSON property healthCheckedTargets



2182
2183
2184
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2182

def health_checked_targets
  @health_checked_targets
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


2187
2188
2189
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2187

def kind
  @kind
end

#locationString

The geo-location granularity is a GCP region. This location string should correspond to a GCP region. e.g. "us-east1", "southamerica-east1", "asia-east1" , etc. Corresponds to the JSON property location

Returns:

  • (String)


2194
2195
2196
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2194

def location
  @location
end

#rrdatasArray<String>

Corresponds to the JSON property rrdatas

Returns:

  • (Array<String>)


2199
2200
2201
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2199

def rrdatas
  @rrdatas
end

#signature_rrdatasArray<String>

DNSSEC generated signatures for all the rrdata within this item. When using health-checked targets for DNSSEC-enabled zones, you can only use at most one health-checked IP address per item. Corresponds to the JSON property signatureRrdatas

Returns:

  • (Array<String>)


2206
2207
2208
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2206

def signature_rrdatas
  @signature_rrdatas
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2213
2214
2215
2216
2217
2218
2219
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2213

def update!(**args)
  @health_checked_targets = args[:health_checked_targets] if args.key?(:health_checked_targets)
  @kind = args[:kind] if args.key?(:kind)
  @location = args[:location] if args.key?(:location)
  @rrdatas = args[:rrdatas] if args.key?(:rrdatas)
  @signature_rrdatas = args[:signature_rrdatas] if args.key?(:signature_rrdatas)
end