Class: Google::Apis::DnsV1beta2::RrSetRoutingPolicyPrimaryBackupPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb

Overview

Configures a RRSetRoutingPolicy such that all queries are responded with the primary_targets if they are healthy. And if all of them are unhealthy, then we fallback to a geo localized policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RrSetRoutingPolicyPrimaryBackupPolicy

Returns a new instance of RrSetRoutingPolicyPrimaryBackupPolicy.



2289
2290
2291
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_geo_targetsGoogle::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicy

Configures a RRSetRoutingPolicy that routes based on the geo location of the querying user. Corresponds to the JSON property backupGeoTargets



2268
2269
2270
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2268

def backup_geo_targets
  @backup_geo_targets
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


2273
2274
2275
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2273

def kind
  @kind
end

#primary_targetsGoogle::Apis::DnsV1beta2::RrSetRoutingPolicyHealthCheckTargets

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both. Corresponds to the JSON property primaryTargets



2281
2282
2283
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2281

def primary_targets
  @primary_targets
end

#trickle_trafficFloat

When serving state is PRIMARY, this field provides the option of sending a small percentage of the traffic to the backup targets. Corresponds to the JSON property trickleTraffic

Returns:

  • (Float)


2287
2288
2289
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2287

def trickle_traffic
  @trickle_traffic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2294
2295
2296
2297
2298
2299
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2294

def update!(**args)
  @backup_geo_targets = args[:backup_geo_targets] if args.key?(:backup_geo_targets)
  @kind = args[:kind] if args.key?(:kind)
  @primary_targets = args[:primary_targets] if args.key?(:primary_targets)
  @trickle_traffic = args[:trickle_traffic] if args.key?(:trickle_traffic)
end