Class: Google::Apis::DnsV1beta2::ManagedZoneDnsSecConfig
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::ManagedZoneDnsSecConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Instance Attribute Summary collapse
-
#default_key_specs ⇒ Array<Google::Apis::DnsV1beta2::DnsKeySpec>
Specifies parameters for generating initial DnsKeys for this ManagedZone.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#non_existence ⇒ String
Specifies the mechanism for authenticated denial-of-existence responses.
-
#state ⇒ String
Specifies whether DNSSEC is enabled, and what mode it is in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedZoneDnsSecConfig
constructor
A new instance of ManagedZoneDnsSecConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedZoneDnsSecConfig
Returns a new instance of ManagedZoneDnsSecConfig.
1040 1041 1042 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_key_specs ⇒ Array<Google::Apis::DnsV1beta2::DnsKeySpec>
Specifies parameters for generating initial DnsKeys for this ManagedZone. Can
only be changed while the state is OFF.
Corresponds to the JSON property defaultKeySpecs
1022 1023 1024 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1022 def default_key_specs @default_key_specs end |
#kind ⇒ String
Corresponds to the JSON property kind
1027 1028 1029 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1027 def kind @kind end |
#non_existence ⇒ String
Specifies the mechanism for authenticated denial-of-existence responses. Can
only be changed while the state is OFF.
Corresponds to the JSON property nonExistence
1033 1034 1035 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1033 def non_existence @non_existence end |
#state ⇒ String
Specifies whether DNSSEC is enabled, and what mode it is in.
Corresponds to the JSON property state
1038 1039 1040 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1038 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1045 1046 1047 1048 1049 1050 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1045 def update!(**args) @default_key_specs = args[:default_key_specs] if args.key?(:default_key_specs) @kind = args[:kind] if args.key?(:kind) @non_existence = args[:non_existence] if args.key?(:non_existence) @state = args[:state] if args.key?(:state) end |