Class: Google::Apis::DnsV1beta2::ManagedZoneOperationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::ManagedZoneOperationsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Instance Attribute Summary collapse
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page displayed.
-
#operations ⇒ Array<Google::Apis::DnsV1beta2::Operation>
The operation resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedZoneOperationsListResponse
constructor
A new instance of ManagedZoneOperationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedZoneOperationsListResponse
Returns a new instance of ManagedZoneOperationsListResponse.
1153 1154 1155 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
1134 1135 1136 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1134 def kind @kind end |
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page
displayed. To fetch the results, make another list request and use this value
as your page token. This lets you retrieve the complete contents of a very
large collection one page at a time. However, if the contents of the
collection change between the first and last paginated list request, the set
of all elements returned are an inconsistent view of the collection. You can't
retrieve a consistent snapshot of a collection larger than the maximum page
size.
Corresponds to the JSON property nextPageToken
1146 1147 1148 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1146 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::DnsV1beta2::Operation>
The operation resources.
Corresponds to the JSON property operations
1151 1152 1153 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1151 def operations @operations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1158 1159 1160 1161 1162 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 1158 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) end |