Class: Google::Apis::DnsV1beta2::ResourceRecordSet
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::ResourceRecordSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Overview
A unit of data that is returned by the DNS servers.
Instance Attribute Summary collapse
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#name ⇒ String
For example, www.example.com.
-
#routing_policy ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicy
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.
-
#rrdatas ⇒ Array<String>
As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see examples.
-
#signature_rrdatas ⇒ Array<String>
As defined in RFC 4034 (section 3.2).
-
#ttl ⇒ Fixnum
Number of seconds that this
ResourceRecordSetcan be cached by resolvers. -
#type ⇒ String
The identifier of a supported record type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceRecordSet
constructor
A new instance of ResourceRecordSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceRecordSet
Returns a new instance of ResourceRecordSet.
2483 2484 2485 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Corresponds to the JSON property kind
2447 2448 2449 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2447 def kind @kind end |
#name ⇒ String
For example, www.example.com.
Corresponds to the JSON property name
2452 2453 2454 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2452 def name @name end |
#routing_policy ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicy
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned
dynamically with the response varying based on configured properties such as
geolocation or by weighted random selection.
Corresponds to the JSON property routingPolicy
2459 2460 2461 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2459 def routing_policy @routing_policy end |
#rrdatas ⇒ Array<String>
As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see
examples.
Corresponds to the JSON property rrdatas
2465 2466 2467 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2465 def rrdatas @rrdatas end |
#signature_rrdatas ⇒ Array<String>
As defined in RFC 4034 (section 3.2).
Corresponds to the JSON property signatureRrdatas
2470 2471 2472 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2470 def signature_rrdatas @signature_rrdatas end |
#ttl ⇒ Fixnum
Number of seconds that this ResourceRecordSet can be cached by resolvers.
Corresponds to the JSON property ttl
2475 2476 2477 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2475 def ttl @ttl end |
#type ⇒ String
The identifier of a supported record type. See the list of Supported DNS
record types.
Corresponds to the JSON property type
2481 2482 2483 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2481 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2488 2489 2490 2491 2492 2493 2494 2495 2496 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2488 def update!(**args) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @routing_policy = args[:routing_policy] if args.key?(:routing_policy) @rrdatas = args[:rrdatas] if args.key?(:rrdatas) @signature_rrdatas = args[:signature_rrdatas] if args.key?(:signature_rrdatas) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) end |