Class: Google::Apis::DnsV1beta2::ResourceRecordSet
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::ResourceRecordSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Overview
A unit of data that is returned by the DNS servers.
Instance Attribute Summary collapse
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#name ⇒ String
For example, www.example.com.
-
#routing_policy ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicy
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.
-
#rrdatas ⇒ Array<String>
As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see examples.
-
#signature_rrdatas ⇒ Array<String>
As defined in RFC 4034 (section 3.2).
-
#ttl ⇒ Fixnum
Number of seconds that this
ResourceRecordSetcan be cached by resolvers. -
#type ⇒ String
The identifier of a supported record type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceRecordSet
constructor
A new instance of ResourceRecordSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceRecordSet
Returns a new instance of ResourceRecordSet.
2421 2422 2423 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2421 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Corresponds to the JSON property kind
2385 2386 2387 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2385 def kind @kind end |
#name ⇒ String
For example, www.example.com.
Corresponds to the JSON property name
2390 2391 2392 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2390 def name @name end |
#routing_policy ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicy
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned
dynamically with the response varying based on configured properties such as
geolocation or by weighted random selection.
Corresponds to the JSON property routingPolicy
2397 2398 2399 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2397 def routing_policy @routing_policy end |
#rrdatas ⇒ Array<String>
As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see
examples.
Corresponds to the JSON property rrdatas
2403 2404 2405 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2403 def rrdatas @rrdatas end |
#signature_rrdatas ⇒ Array<String>
As defined in RFC 4034 (section 3.2).
Corresponds to the JSON property signatureRrdatas
2408 2409 2410 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2408 def signature_rrdatas @signature_rrdatas end |
#ttl ⇒ Fixnum
Number of seconds that this ResourceRecordSet can be cached by resolvers.
Corresponds to the JSON property ttl
2413 2414 2415 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2413 def ttl @ttl end |
#type ⇒ String
The identifier of a supported record type. See the list of Supported DNS
record types.
Corresponds to the JSON property type
2419 2420 2421 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2419 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2426 2427 2428 2429 2430 2431 2432 2433 2434 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2426 def update!(**args) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @routing_policy = args[:routing_policy] if args.key?(:routing_policy) @rrdatas = args[:rrdatas] if args.key?(:rrdatas) @signature_rrdatas = args[:signature_rrdatas] if args.key?(:signature_rrdatas) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) end |