Class: Google::Apis::DnsV1beta2::ResourceRecordSetsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::ResourceRecordSetsListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Instance Attribute Summary collapse
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page displayed.
-
#rrsets ⇒ Array<Google::Apis::DnsV1beta2::ResourceRecordSet>
The resource record set resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceRecordSetsListResponse
constructor
A new instance of ResourceRecordSetsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceRecordSetsListResponse
Returns a new instance of ResourceRecordSetsListResponse.
2525 2526 2527 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2525 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
2506 2507 2508 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2506 def kind @kind end |
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page
displayed. To fetch the results, make another list request and use this value
as your page token. This lets you retrieve the complete contents of a very
large collection one page at a time. However, if the contents of the
collection change between the first and last paginated list request, the set
of all elements returned are an inconsistent view of the collection. You can't
retrieve a consistent snapshot of a collection larger than the maximum page
size.
Corresponds to the JSON property nextPageToken
2518 2519 2520 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2518 def next_page_token @next_page_token end |
#rrsets ⇒ Array<Google::Apis::DnsV1beta2::ResourceRecordSet>
The resource record set resources.
Corresponds to the JSON property rrsets
2523 2524 2525 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2523 def rrsets @rrsets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2530 2531 2532 2533 2534 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2530 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rrsets = args[:rrsets] if args.key?(:rrsets) end |