Class: Google::Apis::DnsV1beta2::ResponsePolicyRulesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::ResponsePolicyRulesListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page displayed.
-
#response_policy_rules ⇒ Array<Google::Apis::DnsV1beta2::ResponsePolicyRule>
The Response Policy Rule resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResponsePolicyRulesListResponse
constructor
A new instance of ResponsePolicyRulesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResponsePolicyRulesListResponse
Returns a new instance of ResponsePolicyRulesListResponse.
2813 2814 2815 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page
displayed. To fetch the results, make another list request and use this value
as your page token. This lets you retrieve the complete contents of a very
large collection one page at a time. However, if the contents of the
collection change between the first and last paginated list request, the set
of all elements returned are an inconsistent view of the collection. You can't
retrieve a consistent snapshot of a collection larger than the maximum page
size.
Corresponds to the JSON property nextPageToken
2806 2807 2808 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2806 def next_page_token @next_page_token end |
#response_policy_rules ⇒ Array<Google::Apis::DnsV1beta2::ResponsePolicyRule>
The Response Policy Rule resources.
Corresponds to the JSON property responsePolicyRules
2811 2812 2813 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2811 def response_policy_rules @response_policy_rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2818 2819 2820 2821 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2818 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @response_policy_rules = args[:response_policy_rules] if args.key?(:response_policy_rules) end |