Class: Google::Apis::DnsV1beta2::RrSetRoutingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::RrSetRoutingPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Overview
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.
Instance Attribute Summary collapse
-
#geo ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicy
Configures a
RRSetRoutingPolicythat routes based on the geo location of the querying user. -
#geo_policy ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicy
Configures a
RRSetRoutingPolicythat routes based on the geo location of the querying user. -
#health_check ⇒ String
The fully qualified URL of the HealthCheck to use for this RRSetRoutingPolicy.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#primary_backup ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyPrimaryBackupPolicy
Configures a RRSetRoutingPolicy such that all queries are responded with the primary_targets if they are healthy.
-
#wrr ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyWrrPolicy
Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion.
-
#wrr_policy ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyWrrPolicy
Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RrSetRoutingPolicy
constructor
A new instance of RrSetRoutingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RrSetRoutingPolicy
Returns a new instance of RrSetRoutingPolicy.
2055 2056 2057 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2055 def initialize(**args) update!(**args) end |
Instance Attribute Details
#geo ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicy
Configures a RRSetRoutingPolicy that routes based on the geo location of the
querying user.
Corresponds to the JSON property geo
2017 2018 2019 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2017 def geo @geo end |
#geo_policy ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicy
Configures a RRSetRoutingPolicy that routes based on the geo location of the
querying user.
Corresponds to the JSON property geoPolicy
2023 2024 2025 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2023 def geo_policy @geo_policy end |
#health_check ⇒ String
The fully qualified URL of the HealthCheck to use for this RRSetRoutingPolicy.
Format this URL like https://www.googleapis.com/compute/v1/projects/project/
global/healthChecks/healthCheck`. https://cloud.google.com/compute/docs/
reference/rest/v1/healthChecks
Corresponds to the JSON propertyhealthCheck`
2031 2032 2033 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2031 def health_check @health_check end |
#kind ⇒ String
Corresponds to the JSON property kind
2036 2037 2038 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2036 def kind @kind end |
#primary_backup ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyPrimaryBackupPolicy
Configures a RRSetRoutingPolicy such that all queries are responded with the
primary_targets if they are healthy. And if all of them are unhealthy, then we
fallback to a geo localized policy.
Corresponds to the JSON property primaryBackup
2043 2044 2045 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2043 def primary_backup @primary_backup end |
#wrr ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyWrrPolicy
Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion.
Corresponds to the JSON property wrr
2048 2049 2050 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2048 def wrr @wrr end |
#wrr_policy ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyWrrPolicy
Configures a RRSetRoutingPolicy that routes in a weighted round robin fashion.
Corresponds to the JSON property wrrPolicy
2053 2054 2055 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2053 def wrr_policy @wrr_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2060 2061 2062 2063 2064 2065 2066 2067 2068 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2060 def update!(**args) @geo = args[:geo] if args.key?(:geo) @geo_policy = args[:geo_policy] if args.key?(:geo_policy) @health_check = args[:health_check] if args.key?(:health_check) @kind = args[:kind] if args.key?(:kind) @primary_backup = args[:primary_backup] if args.key?(:primary_backup) @wrr = args[:wrr] if args.key?(:wrr) @wrr_policy = args[:wrr_policy] if args.key?(:wrr_policy) end |