Class: Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicy
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Overview
Configures a RRSetRoutingPolicy that routes based on the geo location of the
querying user.
Instance Attribute Summary collapse
-
#enable_fencing ⇒ Boolean
(also: #enable_fencing?)
Without fencing, if health check fails for all configured items in the current geo bucket, we failover to the next nearest geo bucket.
-
#items ⇒ Array<Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicyGeoPolicyItem>
The primary geo routing configuration.
-
#kind ⇒ String
Corresponds to the JSON property
kind.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RrSetRoutingPolicyGeoPolicy
constructor
A new instance of RrSetRoutingPolicyGeoPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RrSetRoutingPolicyGeoPolicy
Returns a new instance of RrSetRoutingPolicyGeoPolicy.
2098 2099 2100 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_fencing ⇒ Boolean Also known as: enable_fencing?
Without fencing, if health check fails for all configured items in the current
geo bucket, we failover to the next nearest geo bucket. With fencing, if
health checking is enabled, as long as some targets in the current geo bucket
are healthy, we return only the healthy targets. However, if all targets are
unhealthy, we don't failover to the next nearest bucket; instead, we return
all the items in the current bucket even when all targets are unhealthy.
Corresponds to the JSON property enableFencing
2084 2085 2086 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2084 def enable_fencing @enable_fencing end |
#items ⇒ Array<Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicyGeoPolicyItem>
The primary geo routing configuration. If there are multiple items with the
same location, an error is returned instead.
Corresponds to the JSON property items
2091 2092 2093 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2091 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
2096 2097 2098 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2096 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2103 2104 2105 2106 2107 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2103 def update!(**args) @enable_fencing = args[:enable_fencing] if args.key?(:enable_fencing) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) end |