Class: Google::Apis::DnsV1beta2::RrSetRoutingPolicyGeoPolicyGeoPolicyItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb

Overview

ResourceRecordSet data for one geo location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RrSetRoutingPolicyGeoPolicyGeoPolicyItem

Returns a new instance of RrSetRoutingPolicyGeoPolicyGeoPolicyItem.



2146
2147
2148
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#health_checked_targetsGoogle::Apis::DnsV1beta2::RrSetRoutingPolicyHealthCheckTargets

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both. Corresponds to the JSON property healthCheckedTargets



2120
2121
2122
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2120

def health_checked_targets
  @health_checked_targets
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


2125
2126
2127
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2125

def kind
  @kind
end

#locationString

The geo-location granularity is a GCP region. This location string should correspond to a GCP region. e.g. "us-east1", "southamerica-east1", "asia-east1" , etc. Corresponds to the JSON property location

Returns:

  • (String)


2132
2133
2134
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2132

def location
  @location
end

#rrdatasArray<String>

Corresponds to the JSON property rrdatas

Returns:

  • (Array<String>)


2137
2138
2139
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2137

def rrdatas
  @rrdatas
end

#signature_rrdatasArray<String>

DNSSEC generated signatures for all the rrdata within this item. When using health-checked targets for DNSSEC-enabled zones, you can only use at most one health-checked IP address per item. Corresponds to the JSON property signatureRrdatas

Returns:

  • (Array<String>)


2144
2145
2146
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2144

def signature_rrdatas
  @signature_rrdatas
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2151
2152
2153
2154
2155
2156
2157
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2151

def update!(**args)
  @health_checked_targets = args[:health_checked_targets] if args.key?(:health_checked_targets)
  @kind = args[:kind] if args.key?(:kind)
  @location = args[:location] if args.key?(:location)
  @rrdatas = args[:rrdatas] if args.key?(:rrdatas)
  @signature_rrdatas = args[:signature_rrdatas] if args.key?(:signature_rrdatas)
end