Class: Google::Apis::DnsV1beta2::RrSetRoutingPolicyWrrPolicyWrrPolicyItem
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1beta2::RrSetRoutingPolicyWrrPolicyWrrPolicyItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1beta2/classes.rb,
lib/google/apis/dns_v1beta2/representations.rb,
lib/google/apis/dns_v1beta2/representations.rb
Overview
A routing block which contains the routing information for one WRR item.
Instance Attribute Summary collapse
-
#health_checked_targets ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyHealthCheckTargets
HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#rrdatas ⇒ Array<String>
Corresponds to the JSON property
rrdatas. -
#signature_rrdatas ⇒ Array<String>
DNSSEC generated signatures for all the
rrdatawithin this item. -
#weight ⇒ Float
The weight corresponding to this
WrrPolicyItemobject.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RrSetRoutingPolicyWrrPolicyWrrPolicyItem
constructor
A new instance of RrSetRoutingPolicyWrrPolicyWrrPolicyItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RrSetRoutingPolicyWrrPolicyWrrPolicyItem
Returns a new instance of RrSetRoutingPolicyWrrPolicyWrrPolicyItem.
2426 2427 2428 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_checked_targets ⇒ Google::Apis::DnsV1beta2::RrSetRoutingPolicyHealthCheckTargets
HealthCheckTargets describes endpoints to health-check when responding to
Routing Policy queries. Only the healthy endpoints will be included in the
response. Set either internal_load_balancer or external_endpoints. Do not
set both.
Corresponds to the JSON property healthCheckedTargets
2399 2400 2401 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2399 def health_checked_targets @health_checked_targets end |
#kind ⇒ String
Corresponds to the JSON property kind
2404 2405 2406 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2404 def kind @kind end |
#rrdatas ⇒ Array<String>
Corresponds to the JSON property rrdatas
2409 2410 2411 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2409 def rrdatas @rrdatas end |
#signature_rrdatas ⇒ Array<String>
DNSSEC generated signatures for all the rrdata within this item. When using
health-checked targets for DNSSEC-enabled zones, you can only use at most one
health-checked IP address per item.
Corresponds to the JSON property signatureRrdatas
2416 2417 2418 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2416 def signature_rrdatas @signature_rrdatas end |
#weight ⇒ Float
The weight corresponding to this WrrPolicyItem object. When multiple
WrrPolicyItem objects are configured, the probability of returning an
WrrPolicyItem object's data is proportional to its weight relative to the sum
of weights configured for all items. This weight must be non-negative.
Corresponds to the JSON property weight
2424 2425 2426 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2424 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2431 2432 2433 2434 2435 2436 2437 |
# File 'lib/google/apis/dns_v1beta2/classes.rb', line 2431 def update!(**args) @health_checked_targets = args[:health_checked_targets] if args.key?(:health_checked_targets) @kind = args[:kind] if args.key?(:kind) @rrdatas = args[:rrdatas] if args.key?(:rrdatas) @signature_rrdatas = args[:signature_rrdatas] if args.key?(:signature_rrdatas) @weight = args[:weight] if args.key?(:weight) end |